@@ -92,9 +92,9 @@ def login(request):
             return HTTPFound(location=referrer, headers=headers)
         request.session.flash("Invalid username or password")
 
-    url = edbob.config.get('edbob.pyramid', 'login.logo_url',
+    url = request.rattail_config.get('edbob.pyramid', 'login.logo_url',
                            default=request.static_url('edbob.pyramid:static/img/logo.jpg'))
-    kwargs = eval(edbob.config.get('edbob.pyramid', 'login.logo_kwargs',
+    kwargs = eval(request.rattail_config.get('edbob.pyramid', 'login.logo_kwargs',
                                    default="dict(width=500)"))
 
     return {'form': FormRenderer(form), 'referrer': referrer,
