@@ -143,7 +143,7 @@ class ExecuteBatch(View):
     def execute_batch(self, batch, progress):
         from rattail.db import Session
         session = Session()
-        configure_session(session)
+        configure_session(self.request.rattail_config, session)
         batch = session.merge(batch)
 
         if not batch.execute(progress):
